@@ -1,4 +1,4 @@
-;;; simpleicons.el --- AUCTeX style for `simpleicons.sty' (v14.7.0)  -*- lexical-binding: t; -*-
+;;; simpleicons.el --- AUCTeX style for `simpleicons.sty' (v15.2.0)  -*- lexical-binding: t; -*-
 
 ;; Copyright (C) 2023--2025 Free Software Foundation, Inc.
 
@@ -24,8 +24,8 @@
 
 ;;; Commentary:
 
-;; This file adds support for `simpleicons.sty' (v14.7.0) from
-;; 2025-02-21.  `simpleicons.sty' is part of TeXLive.
+;; This file adds support for `simpleicons.sty' (v15.2.0) from
+;; 2025-06-20.  `simpleicons.sty' is part of TeXLive.
 
 ;;; Code:
 
@@ -33,9 +33,7 @@
 (require 'latex)
 
 ;; Silence the compiler:
-(declare-function font-latex-add-keywords
-                  "font-latex"
-                  (keywords class))
+(declare-function font-latex-add-keywords "font-latex" (keywords class))
 
 (defvar LaTeX-simpleicons-icons
   '("1001tracklists"
@@ -55,9 +53,10 @@
     "7zip"
     "99designs"
     "9gag"
+    "abb"
     "abbott"
-    "abbrobotstudio"
     "abbvie"
+    "abdownloadmanager"
     "aboutdotme"
     "abstract"
     "abusedotch"
@@ -73,6 +72,7 @@
     "actix"
     "actualbudget"
     "acura"
+    "ada"
     "adafruit"
     "adblock"
     "adblockplus"
@@ -142,6 +142,7 @@
     "alienware"
     "aliexpress"
     "alipay"
+    "alist"
     "allegro"
     "alliedmodders"
     "allocine"
@@ -154,32 +155,6 @@
     "altiumdesigner"
     "alwaysdata"
     "alx"
-    "amazon"
-    "amazonalexa"
-    "amazonapigateway"
-    "amazoncloudwatch"
-    "amazoncognito"
-    "amazondocumentdb"
-    "amazondynamodb"
-    "amazonec2"
-    "amazonecs"
-    "amazoneks"
-    "amazonelasticache"
-    "amazonfiretv"
-    "amazongames"
-    "amazoniam"
-    "amazonlumberyard"
-    "amazonluna"
-    "amazonmusic"
-    "amazonpay"
-    "amazonprime"
-    "amazonrds"
-    "amazonredshift"
-    "amazonroute53"
-    "amazons3"
-    "amazonsimpleemailservice"
-    "amazonsqs"
-    "amazonwebservices"
     "amd"
     "ameba"
     "americanairlines"
@@ -205,12 +180,12 @@
     "anta"
     "antdesign"
     "antena3"
+    "antennapod"
     "anthropic"
     "antv"
     "anycubic"
     "anydesk"
     "anytype"
-    "aol"
     "apache"
     "apacheairflow"
     "apacheant"
@@ -330,16 +305,12 @@
     "avast"
     "avianca"
     "avira"
+    "avm"
     "awesomelists"
     "awesomewm"
-    "awsamplify"
-    "awselasticloadbalancing"
-    "awsfargate"
-    "awslambda"
-    "awsorganizations"
-    "awssecretsmanager"
     "awwwards"
     "axios"
+    "axisbank"
     "babel"
     "babelio"
     "babylondotjs"
@@ -348,6 +319,7 @@
     "backbonedotjs"
     "backendless"
     "backstage"
+    "backstagecasting"
     "badoo"
     "baidu"
     "bakalari"
@@ -414,6 +386,7 @@
     "blazemeter"
     "blazor"
     "blender"
+    "blibli"
     "blockbench"
     "blockchaindotcom"
     "blogger"
@@ -429,6 +402,7 @@
     "boat"
     "boehringeringelheim"
     "boeing"
+    "bohemiainteractive"
     "bombardier"
     "bookalope"
     "bookbub"
@@ -448,6 +422,7 @@
     "box"
     "boxysvg"
     "braintree"
+    "brandfetch"
     "brandfolder"
     "brave"
     "breaker"
@@ -467,7 +442,6 @@
     "buffer"
     "bugatti"
     "bugcrowd"
-    "bugsnag"
     "buhl"
     "buildkite"
     "builtbybit"
@@ -530,6 +504,7 @@
     "chainguard"
     "chainlink"
     "chakraui"
+    "changedetection"
     "channel4"
     "charles"
     "chartdotjs"
@@ -551,7 +526,6 @@
     "chinasouthernairlines"
     "chocolatey"
     "chromatic"
-    "chromecast"
     "chromewebstore"
     "chrysler"
     "chupachups"
@@ -598,6 +572,7 @@
     "cnes"
     "cnet"
     "cnn"
+    "cobalt"
     "cocacola"
     "cockpit"
     "cockroachlabs"
@@ -617,7 +592,6 @@
     "codeforces"
     "codefresh"
     "codeigniter"
-    "codeium"
     "codemagic"
     "codementor"
     "codemirror"
@@ -625,6 +599,7 @@
     "codepen"
     "codeproject"
     "coder"
+    "coderabbit"
     "codersrank"
     "coderwall"
     "codesandbox"
@@ -638,7 +613,6 @@
     "coffeescript"
     "coggle"
     "cognizant"
-    "cohost"
     "coinbase"
     "coinmarketcap"
     "collaboraonline"
@@ -712,7 +686,6 @@
     "crystal"
     "csdn"
     "css"
-    "css3"
     "cssdesignawards"
     "cssmodules"
     "csswizardry"
@@ -807,16 +780,19 @@
     "directus"
     "discogs"
     "discord"
+    "discorddotjs"
     "discourse"
     "discover"
     "disqus"
     "disroot"
+    "distrobox"
     "distrokid"
     "django"
     "dji"
     "dlib"
     "dlna"
     "dm"
+    "dmm"
     "docker"
     "docsdotrs"
     "docsify"
@@ -825,6 +801,7 @@
     "dogecoin"
     "doi"
     "dolby"
+    "dolibarr"
     "doordash"
     "dota2"
     "dotenv"
@@ -912,10 +889,9 @@
     "emby"
     "emirates"
     "emlakjet"
-    "empirekred"
     "endeavouros"
-    "engadget"
     "enpass"
+    "ens"
     "enterprisedb"
     "envato"
     "envoyproxy"
@@ -942,9 +918,9 @@
     "etihadairways"
     "etsy"
     "europeanunion"
-    "eventbrite"
     "eventstore"
     "evernote"
+    "everydotorg"
     "excalidraw"
     "exercism"
     "exordo"
@@ -1030,6 +1006,7 @@
     "flipkart"
     "floatplane"
     "flood"
+    "floorp"
     "fluentbit"
     "fluentd"
     "fluke"
@@ -1048,10 +1025,12 @@
     "foodpanda"
     "ford"
     "forgejo"
+    "formbricks"
     "formik"
     "formspree"
     "formstack"
     "fortinet"
+    "fortnite"
     "fortran"
     "fossa"
     "fossilscm"
@@ -1075,10 +1054,12 @@
     "freenas"
     "freenet"
     "freepik"
+    "freetube"
     "fresh"
+    "frigate"
+    "fritz"
     "frontendmentor"
     "frontify"
-    "fsecure"
     "fsharp"
     "fubo"
     "fueler"
@@ -1100,6 +1081,7 @@
     "gameloft"
     "gamemaker"
     "gamescience"
+    "gandi"
     "garmin"
     "gatling"
     "gatsby"
@@ -1140,6 +1122,7 @@
     "gitter"
     "glassdoor"
     "gldotinet"
+    "gleam"
     "glide"
     "glitch"
     "globus"
@@ -1163,7 +1146,6 @@
     "gogdotcom"
     "gojek"
     "goland"
-    "goldenline"
     "goldmansachs"
     "goodreads"
     "google"
@@ -1179,6 +1161,7 @@
     "googlecalendar"
     "googlecampaignmanager360"
     "googlecardboard"
+    "googlecast"
     "googlechat"
     "googlechrome"
     "googlechronicle"
@@ -1191,7 +1174,6 @@
     "googlecontaineroptimizedos"
     "googledataflow"
     "googledataproc"
-    "googledatastudio"
     "googledisplayandvideo360"
     "googledocs"
     "googledrive"
@@ -1219,9 +1201,11 @@
     "googlesheets"
     "googleslides"
     "googlestreetview"
+    "googlesummerofcode"
     "googletagmanager"
     "googletasks"
     "googletranslate"
+    "googletv"
     "gotomeeting"
     "grab"
     "gradio"
@@ -1245,9 +1229,9 @@
     "grocy"
     "groupme"
     "groupon"
-    "grubhub"
     "grunt"
     "gsk"
+    "gsma"
     "gsmarenadotcom"
     "gstreamer"
     "gtk"
@@ -1261,6 +1245,7 @@
     "gurobi"
     "gusto"
     "gutenberg"
+    "h2database"
     "h3"
     "habr"
     "hackaday"
@@ -1285,8 +1270,10 @@
     "hasura"
     "hatenabookmark"
     "haveibeenpwned"
+    "havells"
     "haxe"
     "hbo"
+    "hbomax"
     "hcl"
     "hdfcbank"
     "headlessui"
@@ -1295,6 +1282,7 @@
     "hearth"
     "hearthisdotat"
     "hedera"
+    "hedgedoc"
     "helium"
     "helix"
     "hellofresh"
@@ -1305,7 +1293,9 @@
     "hepsiemlak"
     "here"
     "hermes"
+    "heroicgameslauncher"
     "heroku"
+    "heroui"
     "hetzner"
     "hevy"
     "hexlet"
@@ -1390,6 +1380,7 @@
     "iheartradio"
     "ikea"
     "iledefrancemobilites"
+    "ilovepdf"
     "imagedotsc"
     "imagej"
     "imdb"
@@ -1406,6 +1397,7 @@
     "inductiveautomation"
     "inertia"
     "infiniti"
+    "infinityfree"
     "influxdb"
     "infomaniak"
     "infoq"
@@ -1416,6 +1408,7 @@
     "inkdrop"
     "inkscape"
     "inoreader"
+    "inquirer"
     "insomnia"
     "inspire"
     "insta360"
@@ -1436,6 +1429,7 @@
     "internetcomputer"
     "intigriti"
     "intuit"
+    "invidious"
     "invision"
     "invoiceninja"
     "iobroker"
@@ -1447,6 +1441,7 @@
     "iris"
     "irobot"
     "isc2"
+    "isro"
     "issuu"
     "istio"
     "itchdotio"
@@ -1457,7 +1452,6 @@
     "jabber"
     "jaeger"
     "jaguar"
-    "jamboard"
     "jameson"
     "jamstack"
     "japanairlines"
@@ -1465,6 +1459,7 @@
     "javascript"
     "jbl"
     "jcb"
+    "jdoodle"
     "jeep"
     "jekyll"
     "jellyfin"
@@ -1525,6 +1520,7 @@
     "katana"
     "kaufland"
     "kde"
+    "kdeneon"
     "kdenlive"
     "kdeplasma"
     "kedro"
@@ -1554,6 +1550,7 @@
     "kirby"
     "kit"
     "kitsu"
+    "kiwix"
     "klarna"
     "kleinanzeigen"
     "klm"
@@ -1576,13 +1573,16 @@
     "kong"
     "kongregate"
     "konva"
+    "koreader"
     "kotlin"
     "koyeb"
+    "kred"
     "krita"
     "ktm"
     "ktor"
     "kuaishou"
     "kubernetes"
+    "kubespray"
     "kubuntu"
     "kucoin"
     "kueski"
@@ -1716,6 +1716,7 @@
     "maas"
     "macos"
     "macpaw"
+    "macports"
     "macys"
     "magasinsu"
     "magic"
@@ -1737,6 +1738,7 @@
     "mamp"
     "man"
     "manageiq"
+    "mangaupdates"
     "manjaro"
     "mantine"
     "mapbox"
@@ -1790,7 +1792,6 @@
     "mendeley"
     "mentorcruise"
     "mercadopago"
-    "mercedes"
     "merck"
     "mercurial"
     "mermaid"
@@ -1799,6 +1800,7 @@
     "metabase"
     "metacritic"
     "metafilter"
+    "metager"
     "metasploit"
     "meteor"
     "metro"
@@ -1806,6 +1808,7 @@
     "metrodemadrid"
     "metrodeparis"
     "mewe"
+    "mezmo"
     "mg"
     "microbit"
     "microdotblog"
@@ -1815,6 +1818,7 @@
     "microstrategy"
     "midi"
     "migadu"
+    "mihon"
     "mihoyo"
     "mikrotik"
     "milanote"
@@ -1914,6 +1918,7 @@
     "near"
     "nebula"
     "nec"
+    "nederlandsespoorwegen"
     "neo4j"
     "neovim"
     "neptune"
@@ -1925,6 +1930,7 @@
     "neteasecloudmusic"
     "netflix"
     "netgear"
+    "netim"
     "netlify"
     "nette"
     "netto"
@@ -1932,9 +1938,11 @@
     "newbalance"
     "newegg"
     "newjapanprowrestling"
+    "newpipe"
     "newrelic"
     "newyorktimes"
     "nexon"
+    "nextbike"
     "nextbilliondotai"
     "nextcloud"
     "nextdns"
@@ -1942,7 +1950,6 @@
     "nextdotjs"
     "nextflow"
     "nextra"
-    "nextui"
     "nexusmods"
     "nfc"
     "nfcore"
@@ -1951,6 +1958,7 @@
     "ngrok"
     "ngrx"
     "nhl"
+    "nhost"
     "nicehash"
     "niconico"
     "nike"
@@ -1958,6 +1966,8 @@
     "nim"
     "nissan"
     "nixos"
+    "nobaralinux"
+    "nodebb"
     "nodedotjs"
     "nodemon"
     "nodered"
@@ -1969,6 +1979,7 @@
     "normalizedotcss"
     "norton"
     "norwegian"
+    "notebooklm"
     "notepadplusplus"
     "notion"
     "notist"
@@ -2020,6 +2031,7 @@
     "ollama"
     "omadacloud"
     "oneplus"
+    "onestream"
     "onlyfans"
     "onlyoffice"
     "onnx"
@@ -2035,6 +2047,7 @@
     "openbugbounty"
     "opencollective"
     "opencontainersinitiative"
+    "opencritic"
     "opencv"
     "openfaas"
     "opengl"
@@ -2081,6 +2094,7 @@
     "osf"
     "osgeo"
     "oshkosh"
+    "osmand"
     "osmc"
     "osu"
     "otto"
@@ -2099,6 +2113,7 @@
     "paddle"
     "paddlepaddle"
     "paddypower"
+    "padlet"
     "pagekit"
     "pagerduty"
     "pagespeedinsights"
@@ -2126,6 +2141,7 @@
     "payloadcms"
     "payoneer"
     "paypal"
+    "paysafe"
     "paytm"
     "pcgamingwiki"
     "pdm"
@@ -2214,7 +2230,6 @@
     "plume"
     "pluralsight"
     "plurk"
-    "pluscodes"
     "pm2"
     "pnpm"
     "pocket"
@@ -2225,7 +2240,6 @@
     "podman"
     "poe"
     "poetry"
-    "pointy"
     "polars"
     "polestar"
     "polkadot"
@@ -2237,6 +2251,7 @@
     "popos"
     "porkbun"
     "porsche"
+    "portableappsdotcom"
     "portainer"
     "portswigger"
     "posit"
@@ -2250,6 +2265,7 @@
     "preact"
     "precommit"
     "prefect"
+    "premid"
     "premierleague"
     "prepbytes"
     "prestashop"
@@ -2258,11 +2274,9 @@
     "pretzel"
     "prevention"
     "prezi"
-    "prime"
     "primefaces"
     "primeng"
     "primereact"
-    "primevideo"
     "primevue"
     "printables"
     "prisma"
@@ -2331,8 +2345,10 @@
     "qlik"
     "qmk"
     "qnap"
+    "qodo"
     "qq"
     "qt"
+    "quad9"
     "qualcomm"
     "qualtrics"
     "qualys"
@@ -2360,11 +2376,13 @@
     "racket"
     "radar"
     "radarr"
+    "radiofrance"
     "radixui"
     "radstudio"
     "railway"
     "rainmeter"
     "rakuten"
+    "rakutenkobo"
     "ram"
     "rancher"
     "rapid"
@@ -2437,6 +2455,7 @@
     "retropie"
     "revanced"
     "revealdotjs"
+    "revenuecat"
     "reverbnation"
     "revoltdotchat"
     "revolut"
@@ -2511,6 +2530,7 @@
     "sabanci"
     "safari"
     "sage"
+    "sagemath"
     "sahibinden"
     "sailfishos"
     "sailsdotjs"
@@ -2520,7 +2540,6 @@
     "samsclub"
     "samsung"
     "samsungpay"
-    "sandisk"
     "sanfranciscomunicipalrailway"
     "sanic"
     "sanity"
@@ -2553,6 +2572,7 @@
     "scrumalliance"
     "scrutinizerci"
     "scylladb"
+    "seafile"
     "seagate"
     "searxng"
     "seat"
@@ -2612,6 +2632,7 @@
     "simkl"
     "simpleanalytics"
     "simpleicons"
+    "simplelocalize"
     "simplelogin"
     "simplenote"
     "simplex"
@@ -2662,9 +2683,9 @@
     "sololearn"
     "solus"
     "sonar"
-    "sonarcloud"
-    "sonarlint"
-    "sonarqube"
+    "sonarqubecloud"
+    "sonarqubeforide"
+    "sonarqubeserver"
     "sonarr"
     "sonatype"
     "songkick"
@@ -2804,6 +2825,7 @@
     "swift"
     "swiggy"
     "swiper"
+    "swisscows"
     "swr"
     "symantec"
     "symbolab"
@@ -2852,6 +2874,7 @@
     "telefonica"
     "telegram"
     "telegraph"
+    "telenor"
     "telequebec"
     "temporal"
     "tensorflow"
@@ -2881,9 +2904,11 @@
     "themoviedatabase"
     "thenorthface"
     "theodinproject"
+    "theplanetarysociety"
     "theregister"
     "thesoundsresource"
     "thespritersresource"
+    "thestorygraph"
     "thewashingtonpost"
     "theweatherchannel"
     "thingiverse"
@@ -2955,6 +2980,7 @@
     "treehouse"
     "trello"
     "trendmicro"
+    "tresorit"
     "treyarch"
     "tricentis"
     "trilium"
@@ -2986,8 +3012,10 @@
     "turkishairlines"
     "turso"
     "tuta"
+    "tuxedocomputers"
     "tv4play"
     "tvtime"
+    "twenty"
     "twilio"
     "twinkly"
     "twinmotion"
@@ -3016,6 +3044,7 @@
     "ulule"
     "umami"
     "umbraco"
+    "umbrel"
     "uml"
     "unacademy"
     "underarmour"
@@ -3044,6 +3073,7 @@
     "upstash"
     "uptimekuma"
     "upwork"
+    "uservoice"
     "usps"
     "utorrent"
     "uv"
@@ -3090,6 +3120,7 @@
     "vim"
     "vimeo"
     "vimeolivestream"
+    "vinted"
     "virgin"
     "virginatlantic"
     "virginmedia"
@@ -3110,6 +3141,7 @@
     "vlcmediaplayer"
     "vmware"
     "vodafone"
+    "voelkner"
     "voidlinux"
     "voipdotms"
     "volkswagen"
@@ -3181,6 +3213,7 @@
     "wetransfer"
     "wezterm"
     "wgpu"
+    "what3words"
     "whatsapp"
     "wheniwork"
     "wikibooks"
@@ -3191,9 +3224,11 @@
     "wikimediafoundation"
     "wikipedia"
     "wikiquote"
+    "wikisource"
     "wikiversity"
     "wikivoyage"
     "winamp"
+    "windsurf"
     "wine"
     "wipro"
     "wire"
@@ -3281,6 +3316,7 @@
     "zebratechnologies"
     "zedindustries"
     "zelle"
+    "zenbrowser"
     "zend"
     "zendesk"
     "zenn"
